==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/bvl/src/bvl_bcomp_y.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef BVL_Y_TOKENTYPE
# define BVL_Y_TOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum bvl_y_tokentype {
     tok_AND = 258,
     _BEGIN = 259,
     _END = 260,
     _EQSym = 261,
     _EXIT = 262,
     _FILE = 263,
     _GESym = 264,
     _GTSym = 265,
     _IN = 266,
     _INOUT = 267,
     _LABEL = 268,
     _LESym = 269,
     _LINKAGE = 270,
     _LTSym = 271,
     _NAND = 272,
     _NESym = 273,
     _NEXT = 274,
     _NOR = 275,
     _NOT = 276,
     tok_NULL = 277,
     _OR = 278,
     _OUT = 279,
     _XOR = 280,
     ABS = 281,
     ACCESS = 282,
     AFTER = 283,
     ALIAS = 284,
     ALL = 285,
     ARCHITECTURE = 286,
     ARRAY = 287,
     ASSERT = 288,
     ATTRIBUTE = 289,
     AbstractLit = 290,
     Ampersand = 291,
     Apostrophe = 292,
     Arrow = 293,
     BIT = 294,
     BIT_VECTOR = 295,
     BLOCK = 296,
     BODY = 297,
     BUFFER = 298,
     BUS = 299,
     Bar = 300,
     BasedInt = 301,
     BasedReal = 302,
     BitStringLit = 303,
     Box = 304,
     CASE = 305,
     COMPONENT = 306,
     CONFIGURATION = 307,
     CONSTANT = 308,
     CharacterLit = 309,
     Colon = 310,
     Comma = 311,
     DISCONNECT = 312,
     DOWNTO = 313,
     DecimalInt = 314,
     DecimalReal = 315,
     Dot = 316,
     DoubleStar = 317,
     ELSE = 318,
     ELSIF = 319,
     ENTITY = 320,
     ERROR = 321,
     FOR = 322,
     FS = 323,
     FUNCTION = 324,
     GENERATE = 325,
     GENERIC = 326,
     GUARDED = 327,
     IF = 328,
     IS = 329,
     Identifier = 330,
     LIBRARY = 331,
     LOOP = 332,
     LeftParen = 333,
     MAP = 334,
     MOD = 335,
     MS = 336,
     MUX_BIT = 337,
     MUX_VECTOR = 338,
     Minus = 339,
     NATURAL = 340,
     NATURAL_VECTOR = 341,
     NEW = 342,
     NS = 343,
     OF = 344,
     ON = 345,
     OPEN = 346,
     OTHERS = 347,
     _PACKAGE = 348,
     PORT = 349,
     PROCEDURE = 350,
     PROCESS = 351,
     PS = 352,
     Plus = 353,
     RANGE = 354,
     RECORD = 355,
     REG_BIT = 356,
     REG_VECTOR = 357,
     REGISTER = 358,
     REM = 359,
     REPORT = 360,
     RETURN = 361,
     RightParen = 362,
     SELECT = 363,
     SEVERITY = 364,
     SIGNAL = 365,
     _STABLE = 366,
     SUBTYPE = 367,
     Semicolon = 368,
     Slash = 369,
     Star = 370,
     StringLit = 371,
     THEN = 372,
     TO = 373,
     TRANSPORT = 374,
     _TYPE = 375,
     UNITS = 376,
     UNTIL = 377,
     US = 378,
     USE = 379,
     VARIABLE = 380,
     VarAsgn = 381,
     WAIT = 382,
     WARNING = 383,
     WHEN = 384,
     WHILE = 385,
     WITH = 386,
     WOR_BIT = 387,
     WOR_VECTOR = 388
   };
#endif
/* Tokens.  */
#define tok_AND 258
#define _BEGIN 259
#define _END 260
#define _EQSym 261
#define _EXIT 262
#define _FILE 263
#define _GESym 264
#define _GTSym 265
#define _IN 266
#define _INOUT 267
#define _LABEL 268
#define _LESym 269
#define _LINKAGE 270
#define _LTSym 271
#define _NAND 272
#define _NESym 273
#define _NEXT 274
#define _NOR 275
#define _NOT 276
#define tok_NULL 277
#define _OR 278
#define _OUT 279
#define _XOR 280
#define ABS 281
#define ACCESS 282
#define AFTER 283
#define ALIAS 284
#define ALL 285
#define ARCHITECTURE 286
#define ARRAY 287
#define ASSERT 288
#define ATTRIBUTE 289
#define AbstractLit 290
#define Ampersand 291
#define Apostrophe 292
#define Arrow 293
#define BIT 294
#define BIT_VECTOR 295
#define BLOCK 296
#define BODY 297
#define BUFFER 298
#define BUS 299
#define Bar 300
#define BasedInt 301
#define BasedReal 302
#define BitStringLit 303
#define Box 304
#define CASE 305
#define COMPONENT 306
#define CONFIGURATION 307
#define CONSTANT 308
#define CharacterLit 309
#define Colon 310
#define Comma 311
#define DISCONNECT 312
#define DOWNTO 313
#define DecimalInt 314
#define DecimalReal 315
#define Dot 316
#define DoubleStar 317
#define ELSE 318
#define ELSIF 319
#define ENTITY 320
#define ERROR 321
#define FOR 322
#define FS 323
#define FUNCTION 324
#define GENERATE 325
#define GENERIC 326
#define GUARDED 327
#define IF 328
#define IS 329
#define Identifier 330
#define LIBRARY 331
#define LOOP 332
#define LeftParen 333
#define MAP 334
#define MOD 335
#define MS 336
#define MUX_BIT 337
#define MUX_VECTOR 338
#define Minus 339
#define NATURAL 340
#define NATURAL_VECTOR 341
#define NEW 342
#define NS 343
#define OF 344
#define ON 345
#define OPEN 346
#define OTHERS 347
#define _PACKAGE 348
#define PORT 349
#define PROCEDURE 350
#define PROCESS 351
#define PS 352
#define Plus 353
#define RANGE 354
#define RECORD 355
#define REG_BIT 356
#define REG_VECTOR 357
#define REGISTER 358
#define REM 359
#define REPORT 360
#define RETURN 361
#define RightParen 362
#define SELECT 363
#define SEVERITY 364
#define SIGNAL 365
#define _STABLE 366
#define SUBTYPE 367
#define Semicolon 368
#define Slash 369
#define Star 370
#define StringLit 371
#define THEN 372
#define TO 373
#define TRANSPORT 374
#define _TYPE 375
#define UNITS 376
#define UNTIL 377
#define US 378
#define USE 379
#define VARIABLE 380
#define VarAsgn 381
#define WAIT 382
#define WARNING 383
#define WHEN 384
#define WHILE 385
#define WITH 386
#define WOR_BIT 387
#define WOR_VECTOR 388




#if ! defined BVL_Y_STYPE && ! defined BVL_Y_STYPE_IS_DECLARED
typedef union BVL_Y_STYPE
#line 1353 "../../../src/bvl/src/bvl_bcomp_y.y"
{
	long		 valu;
        float            flov;
	char		*text;
        bvl_ablstr       list;
	bvl_name	 name;
        struct g_type    dble;
	}
/* Line 1489 of yacc.c.  */
#line 324 "y.tab.h"
	BVL_Y_STYPE;
# define bvl_y_stype BVL_Y_STYPE /* obsolescent; will be withdrawn */
# define BVL_Y_STYPE_IS_DECLARED 1
# define BVL_Y_STYPE_IS_TRIVIAL 1
#endif

extern BVL_Y_STYPE bvl_y_lval;

==> alliance_5.0-20120515.orig.tar.gz: alliance-5.0/bvl/src/bvl_bcomp_y.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef BVL_Y_TOKENTYPE
# define BVL_Y_TOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum bvl_y_tokentype {
     tok_AND = 258,
     _BEGIN = 259,
     _END = 260,
     _EQSym = 261,
     _EXIT = 262,
     _FILE = 263,
     _GESym = 264,
     _GTSym = 265,
     _IN = 266,
     _INOUT = 267,
     _LABEL = 268,
     _LESym = 269,
     _LINKAGE = 270,
     _LTSym = 271,
     _NAND = 272,
     _NESym = 273,
     _NEXT = 274,
     _NOR = 275,
     _NOT = 276,
     tok_NULL = 277,
     _OR = 278,
     _OUT = 279,
     _XOR = 280,
     ABS = 281,
     ACCESS = 282,
     AFTER = 283,
     ALIAS = 284,
     ALL = 285,
     ARCHITECTURE = 286,
     ARRAY = 287,
     ASSERT = 288,
     ATTRIBUTE = 289,
     AbstractLit = 290,
     Ampersand = 291,
     Apostrophe = 292,
     Arrow = 293,
     BIT = 294,
     BIT_VECTOR = 295,
     BLOCK = 296,
     BODY = 297,
     BUFFER = 298,
     BUS = 299,
     Bar = 300,
     BasedInt = 301,
     BasedReal = 302,
     BitStringLit = 303,
     Box = 304,
     CASE = 305,
     COMPONENT = 306,
     CONFIGURATION = 307,
     CONSTANT = 308,
     CharacterLit = 309,
     Colon = 310,
     Comma = 311,
     DISCONNECT = 312,
     DOWNTO = 313,
     DecimalInt = 314,
     DecimalReal = 315,
     Dot = 316,
     DoubleStar = 317,
     ELSE = 318,
     ELSIF = 319,
     ENTITY = 320,
     ERROR = 321,
     FOR = 322,
     FS = 323,
     FUNCTION = 324,
     GENERATE = 325,
     GENERIC = 326,
     GUARDED = 327,
     IF = 328,
     IS = 329,
     Identifier = 330,
     LIBRARY = 331,
     LOOP = 332,
     LeftParen = 333,
     MAP = 334,
     MOD = 335,
     MS = 336,
     MUX_BIT = 337,
     MUX_VECTOR = 338,
     Minus = 339,
     NATURAL = 340,
     NATURAL_VECTOR = 341,
     NEW = 342,
     NS = 343,
     OF = 344,
     ON = 345,
     OPEN = 346,
     OTHERS = 347,
     _PACKAGE = 348,
     PORT = 349,
     PROCEDURE = 350,
     PROCESS = 351,
     PS = 352,
     Plus = 353,
     RANGE = 354,
     RECORD = 355,
     REG_BIT = 356,
     REG_VECTOR = 357,
     REGISTER = 358,
     REM = 359,
     REPORT = 360,
     RETURN = 361,
     RightParen = 362,
     SELECT = 363,
     SEVERITY = 364,
     SIGNAL = 365,
     _STABLE = 366,
     SUBTYPE = 367,
     Semicolon = 368,
     Slash = 369,
     Star = 370,
     StringLit = 371,
     THEN = 372,
     TO = 373,
     TRANSPORT = 374,
     _TYPE = 375,
     UNITS = 376,
     UNTIL = 377,
     US = 378,
     USE = 379,
     VARIABLE = 380,
     VarAsgn = 381,
     WAIT = 382,
     WARNING = 383,
     WHEN = 384,
     WHILE = 385,
     WITH = 386,
     WOR_BIT = 387,
     WOR_VECTOR = 388
   };
#endif
/* Tokens.  */
#define tok_AND 258
#define _BEGIN 259
#define _END 260
#define _EQSym 261
#define _EXIT 262
#define _FILE 263
#define _GESym 264
#define _GTSym 265
#define _IN 266
#define _INOUT 267
#define _LABEL 268
#define _LESym 269
#define _LINKAGE 270
#define _LTSym 271
#define _NAND 272
#define _NESym 273
#define _NEXT 274
#define _NOR 275
#define _NOT 276
#define tok_NULL 277
#define _OR 278
#define _OUT 279
#define _XOR 280
#define ABS 281
#define ACCESS 282
#define AFTER 283
#define ALIAS 284
#define ALL 285
#define ARCHITECTURE 286
#define ARRAY 287
#define ASSERT 288
#define ATTRIBUTE 289
#define AbstractLit 290
#define Ampersand 291
#define Apostrophe 292
#define Arrow 293
#define BIT 294
#define BIT_VECTOR 295
#define BLOCK 296
#define BODY 297
#define BUFFER 298
#define BUS 299
#define Bar 300
#define BasedInt 301
#define BasedReal 302
#define BitStringLit 303
#define Box 304
#define CASE 305
#define COMPONENT 306
#define CONFIGURATION 307
#define CONSTANT 308
#define CharacterLit 309
#define Colon 310
#define Comma 311
#define DISCONNECT 312
#define DOWNTO 313
#define DecimalInt 314
#define DecimalReal 315
#define Dot 316
#define DoubleStar 317
#define ELSE 318
#define ELSIF 319
#define ENTITY 320
#define ERROR 321
#define FOR 322
#define FS 323
#define FUNCTION 324
#define GENERATE 325
#define GENERIC 326
#define GUARDED 327
#define IF 328
#define IS 329
#define Identifier 330
#define LIBRARY 331
#define LOOP 332
#define LeftParen 333
#define MAP 334
#define MOD 335
#define MS 336
#define MUX_BIT 337
#define MUX_VECTOR 338
#define Minus 339
#define NATURAL 340
#define NATURAL_VECTOR 341
#define NEW 342
#define NS 343
#define OF 344
#define ON 345
#define OPEN 346
#define OTHERS 347
#define _PACKAGE 348
#define PORT 349
#define PROCEDURE 350
#define PROCESS 351
#define PS 352
#define Plus 353
#define RANGE 354
#define RECORD 355
#define REG_BIT 356
#define REG_VECTOR 357
#define REGISTER 358
#define REM 359
#define REPORT 360
#define RETURN 361
#define RightParen 362
#define SELECT 363
#define SEVERITY 364
#define SIGNAL 365
#define _STABLE 366
#define SUBTYPE 367
#define Semicolon 368
#define Slash 369
#define Star 370
#define StringLit 371
#define THEN 372
#define TO 373
#define TRANSPORT 374
#define _TYPE 375
#define UNITS 376
#define UNTIL 377
#define US 378
#define USE 379
#define VARIABLE 380
#define VarAsgn 381
#define WAIT 382
#define WARNING 383
#define WHEN 384
#define WHILE 385
#define WITH 386
#define WOR_BIT 387
#define WOR_VECTOR 388




#if ! defined BVL_Y_STYPE && ! defined BVL_Y_STYPE_IS_DECLARED
typedef union BVL_Y_STYPE
{

/* Line 1676 of yacc.c  */
#line 1353 "./bvl_bcomp_y.y"

	long		 valu;
        float            flov;
	char		*text;
        bvl_ablstr       list;
	bvl_name	 name;
        struct g_type    dble;
	


/* Line 1676 of yacc.c  */
#line 329 "y.tab.h"
} BVL_Y_STYPE;
# define BVL_Y_STYPE_IS_TRIVIAL 1
# define bvl_y_stype BVL_Y_STYPE /* obsolescent; will be withdrawn */
# define BVL_Y_STYPE_IS_DECLARED 1
#endif

extern BVL_Y_STYPE bvl_y_lval;
